@@ -1,8 +1,10 @@
 package Log::Dispatch::Email;
-$Log::Dispatch::Email::VERSION = '2.43';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.45';
+
 use Log::Dispatch::Output;
 
 use base qw( Log::Dispatch::Output );
@@ -85,7 +87,10 @@ sub flush {
 sub DESTROY {
     my $self = shift;
 
-    if ( in_global_destruction() && @{ $self->{buffer} } ) {
+    if (   in_global_destruction()
+        && $self->{buffered}
+        && @{ $self->{buffer} } ) {
+
         my $name  = $self->name();
         my $class = ref $self;
         my $message
@@ -106,15 +111,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Log::Dispatch::Email - Base class for objects that send log messages via email
 
 =head1 VERSION
 
-version 2.43
+version 2.45
 
 =head1 SYNOPSIS
 
@@ -195,7 +198,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
